@@ -218,29 +218,63 @@ ges_layer_init (GESLayer * self)
   _register_metas (self);
 }
 
+static gint
+ges_layer_resync_priorities_by_type (GESLayer * layer,
+    gint starting_priority, GType type)
+{
+  GstClockTime next_reset = 0;
+  gint priority = starting_priority, max_priority = priority;
+  GList *tmp;
+  GESTimelineElement *element;
+
+  for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
+
+    element = GES_TIMELINE_ELEMENT (tmp->data);
+
+    if (GES_IS_TRANSITION_CLIP (element)) {
+      /* Blindly set transitions priorities to 0 */
+      _set_priority0 (element, 0);
+      continue;
+    } else if (!g_type_is_a (G_OBJECT_TYPE (element), type))
+      continue;
+
+    if (element->start > next_reset) {
+      priority = starting_priority;
+      next_reset = 0;
+    }
+
+    if (element->start + element->duration > next_reset)
+      next_reset = element->start + element->duration;
+
+    _set_priority0 (element, priority);
+    priority = priority + GES_CONTAINER_HEIGHT (element);
+
+    if (priority > max_priority)
+      max_priority = priority;
+  }
+
+  return max_priority;
+}
+
 /**
  * ges_layer_resync_priorities:
  * @layer: a #GESLayer
  *
  * Resyncs the priorities of the clips controlled by @layer.
- * This method
  */
-static gboolean
+gboolean
 ges_layer_resync_priorities (GESLayer * layer)
 {
-  GList *tmp;
-  GESTimelineElement *element;
+  gint min_source_prios;
 
-  GST_DEBUG ("Resync priorities of %p", layer);
+  GST_INFO_OBJECT (layer, "Resync priorities (prio: %d)",
+      layer->priv->priority);
 
-  /* TODO : Inhibit composition updates while doing this.
-   * Ideally we want to do it from an even higher level, but here will
-   * do in the meantime. */
+  min_source_prios = ges_layer_resync_priorities_by_type (layer, 1,
+      GES_TYPE_OPERATION_CLIP);
 
-  for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
-    element = GES_TIMELINE_ELEMENT (tmp->data);
-    _set_priority0 (element, _PRIORITY (element));
-  }
+  ges_layer_resync_priorities_by_type (layer, min_source_prios,
+      GES_TYPE_SOURCE_CLIP);
 
   return TRUE;
 }
@@ -583,8 +617,6 @@ ges_layer_add_clip (GESLayer * layer, GESClip * clip)
     _set_priority0 (GES_TIMELINE_ELEMENT (clip), LAYER_HEIGHT - 1);
   }
 
-  /* If the clip has an acceptable priority, we just let it with its current
-   * priority */
   ges_layer_resync_priorities (layer);
   ges_timeline_element_set_timeline (GES_TIMELINE_ELEMENT (clip),
       layer->timeline);
