@@ -584,7 +584,9 @@ _process_pending_entries (NleComposition * comp)
 
       _nle_composition_remove_object (comp, object);
     } else {
-      _nle_composition_add_object (comp, object);
+      /* take a new ref on object as the current one will be released when
+       * object is removed from pending_io */
+      _nle_composition_add_object (comp, gst_object_ref (object));
     }
   }
 
@@ -688,7 +690,7 @@ _remove_object_func (NleComposition * comp, ChildIOData * childio)
     return;
   }
 
-  g_hash_table_add (priv->pending_io, object);
+  g_hash_table_add (priv->pending_io, gst_object_ref (object));
 
   return;
 }
@@ -738,7 +740,9 @@ _add_object_func (NleComposition * comp, ChildIOData * childio)
     return;
   }
 
-  g_hash_table_add (priv->pending_io, object);
+  /* current reference is hold by the action and will be released with it,
+   * so take a new one */
+  g_hash_table_add (priv->pending_io, gst_object_ref (object));
 }
 
 static void
@@ -765,8 +769,12 @@ _free_action (gpointer udata, Action * action)
 
     gst_event_unref (seekd->event);
     g_slice_free (SeekData, seekd);
-  } else if (ACTION_CALLBACK (action) == _remove_object_func ||
-      ACTION_CALLBACK (action) == _add_object_func) {
+  } else if (ACTION_CALLBACK (action) == _add_object_func) {
+    ChildIOData *iodata = (ChildIOData *) udata;
+
+    gst_object_unref (iodata->object);
+    g_slice_free (ChildIOData, iodata);
+  } else if (ACTION_CALLBACK (action) == _remove_object_func) {
     g_slice_free (ChildIOData, udata);
   } else if (ACTION_CALLBACK (action) == _update_pipeline_func ||
       ACTION_CALLBACK (action) == _commit_func ||
@@ -904,8 +912,8 @@ nle_composition_class_init (NleCompositionClass * klass)
   gstbin_class->handle_message =
       GST_DEBUG_FUNCPTR (nle_composition_handle_message);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&nle_composition_src_template));
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &nle_composition_src_template);
 
   /* Get the paramspec of the NleObject klass so we can do
    * fast notifies */
@@ -974,7 +982,8 @@ nle_composition_init (NleComposition * comp)
   g_mutex_init (&priv->actions_lock);
   g_cond_init (&priv->actions_cond);
 
-  priv->pending_io = g_hash_table_new (g_direct_hash, g_direct_equal);
+  priv->pending_io = g_hash_table_new_full (g_direct_hash, g_direct_equal,
+      gst_object_unref, NULL);
 
   comp->priv = priv;
 
@@ -1231,6 +1240,10 @@ ghost_event_probe_handler (GstPad * ghostpad G_GNUC_UNUSED,
       gst_event_unref (event);
     }
       break;
+    case GST_EVENT_TAG:
+      GST_DEBUG_OBJECT (comp, "Dropping tag: %" GST_PTR_FORMAT, info->data);
+      retval = GST_PAD_PROBE_DROP;
+      break;
     case GST_EVENT_EOS:
     {
       gint seqnum = gst_event_get_seqnum (event);
@@ -1482,6 +1495,13 @@ _seek_current_stack (NleComposition * comp, GstEvent * event,
 
   GST_INFO_OBJECT (comp, "Seeking itself %" GST_PTR_FORMAT, event);
 
+  if (!peer) {
+    GST_ERROR_OBJECT (comp, "Can't seek because no pad available - "
+        "no children in the composition ready to be used, the duration is 0, "
+        "or not committed yet");
+    return FALSE;
+  }
+
   if (flush_downstream) {
     priv->flush_seqnum = gst_event_get_seqnum (event);
     GST_INFO_OBJECT (comp, "sending flushes downstream with seqnum %d",
@@ -2551,7 +2571,7 @@ _relink_children_recursively (NleComposition * comp,
     GST_ELEMENT_ERROR (comp, STREAM, FAILED,
         ("The NleComposition structure is not valid"),
         ("Operation %" GST_PTR_FORMAT
-            " has no child objects to be connected to"
+            " has no child objects to be connected to "
             "current toplevel seek: %" GST_PTR_FORMAT, oper, toplevel_seek));
   }
   /* Make sure we have enough sinkpads */
