@@ -384,25 +384,42 @@ GST_START_TEST (test_snapping)
   CHECK_OBJECT_PROPS (trackelement1, 25, 5, 37);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
-   /**
-   * inpoints           0----------5---------- 0----------
-   *                    |   clip    ||  clip1    ||  clip2   |
-   * time               25---------62-------- 99 --------170
+  /**
+   *                  0----------
+   *                  |   clip  |
+   *                  25--------62
+   * inpoints           5---------- 0---------
+   *                    |  clip1    ||  clip2   |
+   * time               26-------- 62 --------122
    */
+  ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (clip1), 26);
+  ges_timeline_element_set_duration (GES_TIMELINE_ELEMENT (clip1), 37);
+  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
+  CHECK_OBJECT_PROPS (trackelement1, 26, 5, 36);
+  CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
+
+   /**
+   * inpoints           0----------5--------------
+   *                    |   clip    ||  clip1    |
+   * time               25----------62----------99
+   *                                            0-----------
+   *                                            |  clip2   |
+   *                                            98--------168
+   * Check that clip1 snaps with the end of clip */
   fail_unless (ges_timeline_element_ripple (GES_TIMELINE_ELEMENT (clip1),
           58) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 99, 0, 60);
+  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 36);
+  CHECK_OBJECT_PROPS (trackelement2, 98, 0, 60);
 
   /**
-   * inpoints     0----------5----------     0----------
+   * inpoints     0----------- 5------------   0-----------
    *              |   clip    ||  clip1    |   |  clip2    |
-   * time         25---------62-------- 99  110--------170
+   * time         25----------62----------99  110--------170
    */
   ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (clip2), 110);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
+  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 36);
   CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
 
   /**
@@ -413,7 +430,7 @@ GST_START_TEST (test_snapping)
   fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_NORMAL,
           GES_EDGE_NONE, 72) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 73, 5, 37);
+  CHECK_OBJECT_PROPS (trackelement1, 73, 5, 36);
   CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
 
   /**
@@ -424,7 +441,7 @@ GST_START_TEST (test_snapping)
   fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_NORMAL,
           GES_EDGE_NONE, 58) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
+  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 36);
   CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
 
 
@@ -1257,7 +1274,7 @@ _set_track_element_width_height (GESTrackElement * trksrc, gint wvalue,
 }
 
 static gboolean
-check_frame_positionner_size (GESClip * clip, gint width, gint height)
+check_frame_positioner_size (GESClip * clip, gint width, gint height)
 {
   GESTrackElement *trksrc;
   GValue val_width = { 0 };
@@ -1331,7 +1348,7 @@ GST_START_TEST (test_scaling)
    */
 
   /* clip takes the size set on the track as a default */
-  fail_unless (check_frame_positionner_size (clip, 1200, 1000));
+  fail_unless (check_frame_positioner_size (clip, 1200, 1000));
 
   if (GES_IS_VIDEO_SOURCE (GES_CONTAINER_CHILDREN (clip)->data))
     _set_track_element_width_height (GES_CONTAINER_CHILDREN (clip)->data, 1024,
@@ -1349,7 +1366,7 @@ GST_START_TEST (test_scaling)
    */
 
   /* Clip has to comply to direct orders */
-  fail_unless (check_frame_positionner_size (clip, 1024, 768));
+  fail_unless (check_frame_positioner_size (clip, 1024, 768));
 
   GST_DEBUG ("Changing caps, should still be 1024 x 768");
 
@@ -1369,7 +1386,7 @@ GST_START_TEST (test_scaling)
    */
 
   /* Clip still has to be the same size */
-  fail_unless (check_frame_positionner_size (clip, 1024, 768));
+  fail_unless (check_frame_positioner_size (clip, 1024, 768));
 
   GST_DEBUG ("Setting width to 0, should be 1400 x 768");
 
@@ -1389,7 +1406,7 @@ GST_START_TEST (test_scaling)
 
   /* Clip width was set to 0 so it has to use track width */
   /* Clip height is still directly set by the user */
-  fail_unless (check_frame_positionner_size (clip, 1400, 768));
+  fail_unless (check_frame_positioner_size (clip, 1400, 768));
 
   GST_DEBUG ("Setting height to 0, should be 1400 x 1200");
 
@@ -1408,7 +1425,7 @@ GST_START_TEST (test_scaling)
 
   /* Clip width still has to use track width */
   /* Clip height was set to 0 so it has to use track height */
-  fail_unless (check_frame_positionner_size (clip, 1400, 1200));
+  fail_unless (check_frame_positioner_size (clip, 1400, 1200));
 
   GST_DEBUG ("Removing restriction on track height, should be 1400 x 240");
 
@@ -1429,7 +1446,7 @@ GST_START_TEST (test_scaling)
 
   /* Clip width still has to use track width */
   /* Clip height was set to 0 so it has to use natural clip height */
-  fail_unless (check_frame_positionner_size (clip, 1400, 0));
+  fail_unless (check_frame_positioner_size (clip, 1400, 0));
 
   GST_DEBUG ("Removing restriction on track width, should be 320 x 240");
 
@@ -1448,7 +1465,7 @@ GST_START_TEST (test_scaling)
 
   /* Clip width was set to 0 so it has to use natural clip width */
   /* Clip height was set to 0 so it has to use natural clip height */
-  fail_unless (check_frame_positionner_size (clip, 0, 0));
+  fail_unless (check_frame_positioner_size (clip, 0, 0));
 
 
   /**
@@ -1472,7 +1489,7 @@ GST_START_TEST (test_scaling)
    * are changing the aspect ratio, the video should thus not be rescaled. */
   caps = gst_caps_from_string ("video/x-raw,height=1080,width=1920");
   ges_track_set_restriction_caps (trackv, caps);
-  fail_unless (check_frame_positionner_size (clip, 320, 240));
+  fail_unless (check_frame_positioner_size (clip, 320, 240));
 
   gst_object_unref (timeline);
 }
